pub struct ProjectAnalyzer { /* private fields */ }Expand description
Analyzer for detecting project conventions and patterns.
Implementations
Sourceimpl ProjectAnalyzer
impl ProjectAnalyzer
Sourcepub fn current_dir() -> Self
pub fn current_dir() -> Self
Create an analyzer for the current working directory.
Sourcepub fn analyze(&self) -> ProjectConventions
pub fn analyze(&self) -> ProjectConventions
Analyze the project structure and return detected conventions.
Sourcepub fn list_models(&self) -> Vec<String>
pub fn list_models(&self) -> Vec<String>
List all existing model names (snake_case) in the project.
Sourcepub fn model_exists(&self, name: &str) -> bool
pub fn model_exists(&self, name: &str) -> bool
Check if a model exists in the project (case-insensitive).
Sourcepub fn detect_foreign_keys(
&self,
fields: &[(&str, &str)],
) -> Vec<ForeignKeyInfo>
pub fn detect_foreign_keys( &self, fields: &[(&str, &str)], ) -> Vec<ForeignKeyInfo>
Detect foreign key relationships from a list of fields.
Fields ending in _id are considered potential foreign keys.
Returns information about each detected FK including whether
the target model exists in the project.