pub fn parse_existing(path: &Path) -> Option<PreservedAppYamlIdentity>Expand description
Read identity fields from an existing .do/app.yaml.
Returns None when the file does not exist or cannot be read.
Returns Some(identity) otherwise; individual fields within the struct
are None when the corresponding key was not found in the file.