pub fn find_ferro_path_deps(content: &str) -> Vec<String>
Walk dependency tables of a parsed Cargo.toml string and collect every key starting with ferro whose value is a table containing a path field.
ferro
path