pub fn detect_dirs(root: &Path) -> ProjectDirsExpand description
Probe the project root for the optional directories used by the deploy scaffold templates.
pub fn detect_dirs(root: &Path) -> ProjectDirsProbe the project root for the optional directories used by the deploy scaffold templates.